html, body { height: auto; }

#content { margin: 0 5px; }

#container { margin: 0; min-width: 240px !important; }

#branding { display: none; }

.login #branding { display: block; }

#user-tools { position: relative; text-align: center; }

.module { border: none; box-shadow: none; padding: 5px 0 5px 0 !important; -moz-box-shadow: none !important; -webkit-box-shadow: none !important; -o-box-shadow: none !important; box-shadow: none !important; }
.module caption { margin-bottom: 5px; margin-left: 5px; }

div.breadcrumbs { padding-left: 5px; }

.plugin-holder { display: none !important; }

body.login #container { width: auto !important; max-width: 320px; }
body.login #container #content #content-main .form-row, body.login #container #content #content-main .submit-row { text-align: center; }
body.login #container #content #content-main .form-row input { width: auto !important; max-width: none; min-width: 40px; }
body.login #container #content #content-main .submit-row input, body.login #container #content #content-main .submit-row input[type="submit"] { width: 80% !important; }

.colMS { margin-right: 10px !important; }

.dashboard #container #content h1 { display: none; }
.dashboard #container #content-main { min-width: 0; max-width: none; float: none; }
.dashboard #container #content-main .addlink, .dashboard #container #content-main .changelink { text-indent: -9999px; overflow: hidden; }
.dashboard #container #content-related { width: auto; float: none; margin-right: 0; }
.dashboard #container #content-related .module { padding: 10px !important; margin: 10px 0; }
.dashboard #container #content-related .module .actionlist { margin-left: 10px; }
.dashboard .module { background: none !important; }

.change-list #content { margin-top: 38px; }
.change-list #content > h1 { display: none; }
.change-list #content .object-tools { margin: -33px 0 0 0; }
.change-list #toolbar label { display: inline-block; }
.change-list #toolbar form #searchbar { width: 120px; }
.change-list #toolbar .small { display: block; }
.change-list .filtered .results, .change-list .change-list .filtered .paginator, .change-list .filtered #toolbar, .change-list .filtered div.xfull { margin-right: 0 !important; }
.change-list .module #changelist-form .results { width: 100%; overflow: auto; }
.change-list .filtered .actions, .change-list .filtered .paginator { margin-right: 0 !important; }

#changelist-filter-button, #changelist-filter { display: none !important; }

.tree { background: white; }

#sitemap li .col-softroot, #sitemap li .col-language, #sitemap li .col-actions, #sitemap li .col-published, #sitemap li .col-navigation, #sitemap li .col-moderator, #sitemap li .col-lastchange, #sitemap li .col-draft, #sitemap li .col-view-perms, #sitemap li .col-creator { display: none !important; }

#sitemap li .col-softroot, #sitemap li .col-language { display: block !important; }

.change-form #content { margin-top: 45px; }
.change-form #content > h1 { display: none; }
.change-form .object-tools { margin: -35px 0 0 0; }

#page_form_lang_tabs input { font-weight: normal !important; font-size: 11px !important; padding: 2px 4px !important; }

form label, .aligned label { display: block; padding: 0 !important; float: none !important; line-height: 14px; margin-top: 5px; }

form input, form input[type="file"], form textarea, form select { width: auto; /*max-width: 200px;*/ }
form .vTextField { width: auto; }
form .aligned p, form .aligned ul { padding-left: 0 !important; margin-left: 0 !important; }
form .submit-row { text-align: left; }

.inline-group { padding: 5px; margin-bottom: 10px; }
.inline-group .module h2 { padding-left: 5px; }

.selector { width: auto; float: none; }
.selector .selector-available, .selector .selector-chosen { width: auto; float: none; }
.selector .selector-available p, .selector .selector-chosen p { text-align: center; }
.selector .selector-chosen { margin-top: 60px; }
.selector ul.selector-chooser { margin-top: 0; display: block; }
.selector select[multiple], .selector select { max-width: none; width: 100%; }
.selector label { display: inline-block; }
.selector .selector-available input, .selector .selector-chosen input { width: auto; }
