@warn "This import is deprecated. Use 'compass/typography/lists' instead.";

@import "../typography/lists/_horizontal-list.scss";
@import "../typography/lists/_inline-list.scss";
@import "../typography/lists/_inline-block-list.scss";
@import "../typography/lists/_bullets.scss";
