@warn "This import is deprecated. Use 'compass/typography/text' instead.";

@import "../typography/text/_ellipsis.scss";
@import "../typography/text/_nowrap.scss";
@import "../typography/text/_replacement.scss";
