@warn "This import is deprecated. Use 'compass/typography/links' instead.";

@import "../typography/links/_hover-link.scss";
@import "../typography/links/_link-colors.scss";
@import "../typography/links/_unstyled-link.scss";
